==> 1.8-02.11.11.tar.gz: 1.8/bauenf.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import pygame 


"""
def bauen_weg(monde,draw,mouse,neu):
	#global monde, draw
	if pygame.mouse.get_pressed()[0] == True:
		for o in draw:
			if o["rect"].contains(pygame.Rect((mouse[0],mouse[1],20,20))):
				if o["size"] == [1,1]:
					print o["pos"]
					monde[o["pos"][0]][o["pos"][1]]["img"] = neu[2]["img"]
					monde[o["pos"][0]][o["pos"][1]]["type"] = 2
	return monde		
"""


def bauen_weg(monde,draw,mouse,neu,bauen):
	
	b = bauen["type"]
	ok = False

	### nur wenn linke maustaste down
	if pygame.mouse.get_pressed()[0] == True:
		### heraussuchen des aktuellen Felds aus den angezeigten Felder 
		for o in draw:
			if o["rect"].contains(pygame.Rect((mouse[0],mouse[1],20,20))):
				if o["size"] == [1,1]:
					obj = monde[o["pos"][0]][o["pos"][1]]		# temp variabel, so das das arbeiten einfacher wird
					## erstes Feld markiert begin des zu zeichnenden Weges
					if bauen.get("begin") == None:		
						bauen["begin"] = obj["pos"]  
						bauen["weg"] = [obj]
					## aktuelles Feld markiert ende des Wege Rechtecks	
					bauen["end"] = obj["pos"]
					## links rects gerade aus filtern, spaeter andere bilder etc
					if bauen["end"][0] == bauen["weg"][-1]["pos"][0] +1:		# x
						ok = True
					if bauen["end"][1] == bauen["weg"][-1]["pos"][1] +1:		# y
						ok = True
					if bauen["end"][0] == bauen["weg"][-1]["pos"][0] -1:		# -x
						ok = True
					if bauen["end"][1] == bauen["weg"][-1]["pos"][1] -1:		# -y
						ok = True
					# bauen
					if (ok == True) or (len(bauen["weg"]) == 1):
						bauen["weg"].append(obj)
						bauen["weg"][-1]["typ"] = neu[b]
						bauen["weg"][-1]["dpos"][0] = bauen["weg"][-1]["npos"][0] # da wege keien korrektur brauchen
						bauen["weg"][-1]["dpos"][1] = bauen["weg"][-1]["npos"][1] # da wege keien korrektur brauchen
						bauen["weg"][-1]["datei"] = neu[b]["datei"]
						bauen["weg"][-1]["img"] = neu[b]["img"]
						bauen["weg"][-1]["rect"] = neu[b]["img"].get_rect().move(bauen["weg"][-1]["dpos"])
					
					print "baue wegelement on " + str(bauen["weg"][-1]["pos"])
	### wird maustaste wieder losgelassen
	if pygame.mouse.get_pressed()[0] == False:
		if bauen.get("weg") != None:
			for c in bauen["weg"]:
				monde[c["pos"][0]][c["pos"][1]] = c
		bauen = {"type" : bauen["type"] } # reset von bauen
	return {"monde" : monde,"bauen" : bauen}  # ausgabe von monde und bauen , bauen ermöglicht ein beibehalten der zu bauenden felder








def bauen_feld(monde,draw,mouse,neu,bauen,z):
	s=[]
	r=0
	cost=0
	if z == 0:
		s = [26,15]
		r=10
	elif z == 1:
		s = [52,30]
		r=20
	elif z == 2:
		s = [104,60]
		r=40
	b = bauen["type"]
	### nur wenn linke maustaste down
	if pygame.mouse.get_pressed()[0] == True:
		### heraussuchen des aktuellen Felds aus den angezeigten Felder 
		for o in draw:
			if o["rect"].contains(pygame.Rect((mouse[0]-(r/2),mouse[1]-(r/2),r,r))):
				if o["size"] == [1,1]:
					obj = monde[o["pos"][0]][o["pos"][1]]		# temp variabel, so das das arbeiten einfacher wird
					## erstes Feld markiert begin des zu zeichnenden Feldes 
					if bauen.get("begin") == None:		
						bauen["begin"] = obj["pos"]  
					## aktuelles Feld markiert ende des Feld Rechtecks	
					bauen["end"] = obj["pos"] 
					bauen["rect"] = [[],[]]
					## Rechteck erstellen
					if bauen["end"][0] - bauen["begin"][0] >= 0:	## x richtung
						bauen["rect"][0] = range(bauen["begin"][0] , bauen["end"][0]+1)
					if bauen["end"][0] - bauen["begin"][0] <= 0:	## -x richtung
						bauen["rect"][0] = range(bauen["end"][0] , bauen["begin"][0]+1)
					if bauen["end"][1] - bauen["begin"][1] >= 0:	## y richtung
						bauen["rect"][1] = range(bauen["begin"][1] , bauen["end"][1]+1)
					if bauen["end"][1] - bauen["begin"][1] <= 0:	## -y richtung
						bauen["rect"][1] = range(bauen["end"][1] , bauen["begin"][1]+1)	
					

	### wird maustaste  losgelassen
	if (pygame.mouse.get_pressed()[0] == False) and (bauen.get("rect") != None): #and ( rect != [[],[]]) 
		rect = bauen["rect"] 
		print "baue Feld von " + str(bauen["begin"]) + " bis " + str(bauen["end"]) + "vom Typ " + str(bauen["type"])
 		## jedes Feld in bauen durchgehen, so dass ein Rechteck von begin zu ende entsteht
		c=0
		for i in rect[0]:
			for i2 in rect[1]:
				c=c+1
				obj2 = monde[i][i2] # erneute temp variabel
				# folge links: ist link existent aund bauen true , oder ist link inexistent und bauen true
				if ((obj2.get("link") == None) and (obj2["bauen"] == 1 )) or ((obj2.get("link") != None) and (monde[obj2["link"][0]][obj2["link"][1]]["bauen"] == 1 )):
					obj2["img"] = neu[b]["img"]  # kopiere img aus neu 
					obj2["datei"] = neu[b]["datei"]  # kopiere datei namen aus neu 
					obj2["rect"] = obj2["img"].get_rect() 
					## errechnen der Korrektur
					korrektur = obj2["rect"].height - obj2["size"][1]*s[1]
					obj2["korr"] = korrektur
					## rest 
					obj2["dpos"] = [obj2["npos"][0],obj2["npos"][1] - korrektur]
					obj2["rect"] = obj2["rect"].move(obj2["dpos"])
					obj2["type"] = b
					monde[i][i2] = obj2
		bauen = {"type" : bauen["type"] } # reset von bauen
		cost = neu[b]["cost"]*c
		print "cost: " + str(cost)
	return {"monde" : monde,"bauen" : bauen,"cost":cost}  # ausgabe von monde und bauen , bauen ermöglicht ein beibehalten der zu bauenden felder



def bauen_haus(monde,draw,mouse,neu,bauen,z):
	s=[] 
	r=0
	cost=0
	if z == 0:
		s = [26,15]
		r=10
	elif z == 1:
		s = [52,30]
		r=20
	elif z == 2:
		s = [104,60]
		r=40
	b = bauen["type"]	# bautyp , für neu index
	ok = True		# Bebaubar?
	
	# mouse pressed
	#----------------------
	if pygame.mouse.get_pressed()[0] == True:
		for o in draw:
			# aus draw passende Koordinaten suchen
			if o["rect"].contains(pygame.Rect((mouse[0]-(r/2),mouse[1]-(r/2),r,r))):		
				
				# bebaubar test
				#	--------------------------
				for x in range(o["pos"][0],o["pos"][0]+neu[b]["size"][0]):		# von position bis position + size
					for y in range(o["pos"][1],o["pos"][1]+neu[b]["size"][1]):
						# gehe links nach
						if monde[x][y].get("link") != None:
							if monde[monde[x][y]["link"][0]][monde[x][y]["link"][1]]["bauen"] == 0:
								ok = False
						# gibt est eine Koordinate, die nicht bebaubar ist, wird ok = False							
						elif monde[x][y]["bauen"] == 0:
							ok = False
				del x , y   	# da x und y häufig sind
				
				# ist alles bebaubar, geht's los!
				# -------------------------------------
				if ok == True:
					obj = monde[o["pos"][0]][o["pos"][1]]		# temp var , besser manipulierbar als monde	
					
					bauen = obj	# hérédité der alten eigenschaften
					# ungeschickt alle attribute manuell festzulegen , besser iter oder so
					bauen["type"] = b
					bauen["bauen"] = 0
					bauen["size"] = neu[b]["size"]		# needed by korrektur
					bauen["img"] = neu[b]["img"] 		# needed by korrektur
					bauen["datei"] = neu[b]["datei"] 		
					bauen["rect"] = bauen["img"].get_rect()		# needed by korrektur
					# korrektur + positionieren
					korrektur = bauen["rect"].height - bauen["size"][1]*s[1]+s[1]		# warum +60?
					bauen["dpos"] = [obj["npos"][0],obj["npos"][1]-korrektur]
					bauen["rect"] = bauen["rect"].move(bauen["dpos"])
					
	# mouse depressed (hehe)
	#---------------------------------					
	if (pygame.mouse.get_pressed()[0] == False) and (bauen.get("pos") != None):		# ist überhaubt gebaut woden?
		monde[bauen["pos"][0]][bauen["pos"][1]] = bauen		# übergabe von temp var bauen
		print "baue Haus auf " + str(bauen["pos"])  
		# erstellen der Links 
		for x in range(bauen["pos"][0],bauen["pos"][0]+bauen["size"][0]):		# siehe test ob bebaubar
			for y in range(bauen["pos"][1],bauen["pos"][1]+bauen["size"][1]):
				if not ((x == bauen["pos"][0]) and (y == bauen["pos"][1])):		# erste koordinate natürlich nicht überschreiben (ref)
					npos = monde[x][y]["npos"]
					monde[x][y] = {"pos" : monde[x][y]["pos"] , "link" : bauen["pos"] , "npos":npos}	# links
		bauen = {"type" : bauen["type"] } # reset von bauen
		cost = neu[b]["cost"]
	return {"monde" : monde,"bauen" : bauen , "cost": cost}  # ausgabe von monde und bauen , bauen ermöglicht ein beibehalten der zu bauenden felder




	
def delete(monde,draw,mouse,neu,bauen,z):
	s=[]
	r=0
	cost=0
	if z == 0:
		s = [26,15]
		r=10
	elif z == 1:
		s = [52,30]
		r=20
	elif z == 2:
		s = [104,60]
		r=40
	b = 1
	### nur wenn linke maustaste down
	if pygame.mouse.get_pressed()[0] == True:
		### heraussuchen des aktuellen Felds aus den angezeigten Felder 
		for o in draw:
			if o["rect"].contains(pygame.Rect((mouse[0]-(r/2),mouse[1]-(r/2),r,r))):
				if o["size"] == [1,1]:		# bei einfachen objekten
					obj = monde[o["pos"][0]][o["pos"][1]]		# temp variabel, so das das arbeiten einfacher wird
					## erstes Feld markiert begin des zu zeichnenden Feldes 
					if bauen.get("begin") == None:		
						bauen["begin"] = obj["pos"]  
					## aktuelles Feld markiert ende des Feld Rechtecks	
					bauen["end"] = obj["pos"] 
					bauen["rect"] = [[],[]]
					## Rechteck erstellen
					if bauen["end"][0] - bauen["begin"][0] >= 0:	## x richtung
						bauen["rect"][0] = range(bauen["begin"][0] , bauen["end"][0]+1)
					if bauen["end"][0] - bauen["begin"][0] <= 0:	## -x richtung
						bauen["rect"][0] = range(bauen["end"][0] , bauen["begin"][0]+1)
					if bauen["end"][1] - bauen["begin"][1] >= 0:	## y richtung
						bauen["rect"][1] = range(bauen["begin"][1] , bauen["end"][1]+1)
					if bauen["end"][1] - bauen["begin"][1] <= 0:	## -y richtung
						bauen["rect"][1] = range(bauen["end"][1] , bauen["begin"][1]+1)
				
				if o["size"] != [1,1]:		# für objekte wie häuser
					bauen["rect"] = [[],[]]
					bauen["rect"][0] = range(o["pos"][0],o["pos"][0]+o["size"][0])
					bauen["rect"][1] = range(o["pos"][1],o["pos"][1]+o["size"][1])
					bauen["begin"] = o["pos"] 
					bauen["end"] = [o["pos"][0]+o["size"][0],o["pos"][1]+o["size"][1]]

	### wird maustaste  losgelassen
	if (pygame.mouse.get_pressed()[0] == False) and (bauen.get("rect") != None):
		rect = bauen["rect"] 
		print "baue Feld von " + str(bauen["begin"]) + " bis " + str(bauen["end"]) + "vom Typ " + str(bauen["type"])
 		## jedes Feld in bauen durchgehen, so dass ein Rechteck von begin zu ende entsteht
		for i in rect[0]:
			for i2 in rect[1]:
				obj2 = monde[i][i2] # erneute temp variabel
				# folge links: ist link existent aund bauen true , oder ist link inexistent und bauen true
			#	if ((obj2.get("link") == None)):
				obj2["img"] = neu[b]["img"]  # kopiere img aus neu 
				obj2["datei"] = neu[b]["datei"]  # kopiere datei namen aus neu 
				obj2["rect"] = obj2["img"].get_rect() 
				## errechnen der Korrektur (1 und 2 sind gleich null!)
				## rest 
				obj2["dpos"] = [obj2["npos"][0],obj2["npos"][1]]
				obj2["rect"] = obj2["rect"].move(obj2["dpos"])
				obj2["type"] = 1
				obj2["bauen"] = 1
				obj2["korr"] = 0
				obj2["size"] = [1,1]
				if obj2.get("link") != None:
					del obj2["link"]
				monde[i][i2] = obj2
		bauen = {"type" : bauen["type"] } # reset von bauen
	return {"monde" : monde,"bauen" : bauen}  # ausgabe von monde und bauen , bauen ermöglicht ein beibehalten der zu bauenden felder

==> 2.2--27.12.11.tar.gz: 2.2/bauenf.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import pygame 
import load
import chemin

gueter = [110]

def bauen_weg(monde,draw,wege,nodes,mouse,neu,bauen,players,pla):
	
	b = bauen["type"]
	wege3=wege
	### nur wenn linke maustaste down
	if pygame.mouse.get_pressed()[0] == True:
		### heraussuchen des aktuellen Felds aus den angezeigten Felder 
		for o in draw:
			if o["rect"].contains(pygame.Rect((mouse[0],mouse[1],20,20))):
				if o["size"] == [1,1]:
					obj = monde[o["pos"][0]][o["pos"][1]]		# temp variabel, so das das arbeiten einfacher wird
					
					## erstes Feld markiert begin des zu zeichnenden Weges
					if bauen.get("begin") == None:		
						bauen["begin"] = obj["pos"]  
					bauen["weg"] = [obj]	# immer 1 objekt in "weg"; überschreiben des letzten weges
					
					## aktuelles Feld markiert ende des Wege Rechtecks	
					bauen["end"] = obj["pos"]
					bauen["rect"] = [[],[]]
					## Rechteck erstellen
					if bauen["end"][0] - bauen["begin"][0] >= 0:	## x richtung
						bauen["rect"][0] = range(bauen["begin"][0] , bauen["end"][0]+1)
					if bauen["end"][0] - bauen["begin"][0] <= 0:	## -x richtung
						bauen["rect"][0] = range(bauen["end"][0] , bauen["begin"][0]+1)
					if bauen["end"][1] - bauen["begin"][1] >= 0:	## y richtung
						bauen["rect"][1] = range(bauen["begin"][1] , bauen["end"][1]+1)
					if bauen["end"][1] - bauen["begin"][1] <= 0:	## -y richtung
						bauen["rect"][1] = range(bauen["end"][1] , bauen["begin"][1]+1)	

					## jedes Feld in bauen durchgehen, so dass ein Rechteck von begin zu ende entsteht
					rect = bauen["rect"] 
					for i in rect[0]:
						for i2 in rect[1]:
							obj2 = monde[i][i2] # erneute temp variabel
							
							#							i=end[0]
							#							 |	
							#							 v		
							#i2=begin[1]	->	b=========
							#i2!=begin[1]	->	        ||
							#i2!=begin[1]	->	        ||
							#		    			    e
							# baue weg nur wenn die aktuelle y koord die des begins  ist (horizontal) oder wenn die aktuelle x variabel die des endes ist (vertikal)
							if (i2 == bauen["begin"][1]) or (i2 != bauen["begin"][1] and i == bauen["end"][0]):
								# ist link inexistent und bauen genemigt
								if ((obj2.get("link") == None) and (obj2["bauen"] == 1 )):
									bauen["weg"].append(obj2)
									#print "baue wegelement on " + str(bauen["weg"][-1]["pos"])
	
	### wird maustaste wieder losgelassen
	if (pygame.mouse.get_pressed()[0] == False) and (bauen.get("weg") != None):
		for c in bauen["weg"]:
			#c["typ"] = neu[b]
			c["type"] = b
			c["dpos"][0] = c["npos"][0] # da wege keien korrektur brauchen
			c["dpos"][1] = c["npos"][1] # da wege keien korrektur brauchen
			c["datei"] = neu[b]["datei"]
			c["img"] = neu[b]["img"]
			c["rect"] = neu[b]["img"].get_rect().move(c["dpos"])
			monde[c["pos"][0]][c["pos"][1]] = c
		bauen = {"type" : bauen["type"] } # reset von bauen
		
		wege2 = load.lade_wege(monde)
		wege3=[]
		for x in wege2:
			for y in x:
				if y != []:
					wege3.append(y)
		nodes = chemin.find_nodes(wege3)
	return {"monde" : monde,"bauen" : bauen,"players":players,"wege":wege3,"nodes":nodes}  # ausgabe von monde und bauen , bauen ermöglicht ein beibehalten der zu bauenden felder








def bauen_feld(monde,draw,mouse,neu,bauen,z,players,pla):
	s=[]
	r=0
	cost=0
	if z == 0:
		s = [26,15]
		r=10
	elif z == 1:
		s = [52,30]
		r=20
	elif z == 2:
		s = [104,60]
		r=40
	b = bauen["type"]
	### nur wenn linke maustaste down
	if pygame.mouse.get_pressed()[0] == True:
		### heraussuchen des aktuellen Felds aus den angezeigten Felder 
		for o in draw:
			if o["rect"].contains(pygame.Rect((mouse[0]-(r/2),mouse[1]-(r/2),r,r))):
				if o["size"] == [1,1]:
					obj = monde[o["pos"][0]][o["pos"][1]]		# temp variabel, so das das arbeiten einfacher wird
					## erstes Feld markiert begin des zu zeichnenden Feldes 
					if bauen.get("begin") == None:		
						bauen["begin"] = obj["pos"]  
					## aktuelles Feld markiert ende des Feld Rechtecks	
					bauen["end"] = obj["pos"] 
					bauen["rect"] = [[],[]]
					## Rechteck erstellen
					if bauen["end"][0] - bauen["begin"][0] >= 0:	## x richtung
						bauen["rect"][0] = range(bauen["begin"][0] , bauen["end"][0]+1)
					if bauen["end"][0] - bauen["begin"][0] <= 0:	## -x richtung
						bauen["rect"][0] = range(bauen["end"][0] , bauen["begin"][0]+1)
					if bauen["end"][1] - bauen["begin"][1] >= 0:	## y richtung
						bauen["rect"][1] = range(bauen["begin"][1] , bauen["end"][1]+1)
					if bauen["end"][1] - bauen["begin"][1] <= 0:	## -y richtung
						bauen["rect"][1] = range(bauen["end"][1] , bauen["begin"][1]+1)	
					

	### wird maustaste  losgelassen
	if (pygame.mouse.get_pressed()[0] == False) and (bauen.get("rect") != None): #and ( rect != [[],[]]) 
		rect = bauen["rect"] 
		print "baue Feld von " + str(bauen["begin"]) + " bis " + str(bauen["end"]) + "vom Typ " + str(bauen["type"])
 		## jedes Feld in bauen durchgehen, so dass ein Rechteck von begin zu ende entsteht
		c=0
		for i in rect[0]:
			for i2 in rect[1]:
				c=c+1
				obj2 = monde[i][i2] # erneute temp variabel
				# folge links: ist link existent aund bauen true , oder ist link inexistent und bauen true
				if ((obj2.get("link") == None) and (obj2["bauen"] == 1 )) or ((obj2.get("link") != None) and (monde[obj2["link"][0]][obj2["link"][1]]["bauen"] == 1 )):
					obj2["img"] = neu[b]["img"]  # kopiere img aus neu 
					obj2["datei"] = neu[b]["datei"]  # kopiere datei namen aus neu 
					obj2["rect"] = obj2["img"].get_rect() 
					## errechnen der Korrektur
					korrektur = obj2["rect"].height - obj2["size"][1]*s[1]
					obj2["korr"] = korrektur
					## rest 
					obj2["dpos"] = [obj2["npos"][0],obj2["npos"][1] - korrektur]
					obj2["rect"] = obj2["rect"].move(obj2["dpos"])
					obj2["type"] = b
					monde[i][i2] = obj2
		bauen = {"type" : bauen["type"] } # reset von bauen
		cost = neu[b]["cost"]*c
		print "cost: " + str(cost)
	return {"monde" : monde,"bauen" : bauen,"cost":cost,"players":players}  # ausgabe von monde und bauen , bauen ermöglicht ein beibehalten der zu bauenden felder



def bauen_haus(monde,draw,mouse,neu,bauen,z,players,pla):
	global gueter
	s=[] 
	r=0
	cost=0
	if z == 0:
		s = [26,15]
		r=10
	elif z == 1:
		s = [52,30]
		r=20
	elif z == 2:
		s = [104,60]
		r=40
	b = bauen["type"]	# bautyp , für neu index
	ok = True		# Bebaubar?
	
	# mouse pressed
	#----------------------
	if pygame.mouse.get_pressed()[0] == True:
		for o in draw:
			# aus draw passende Koordinaten suchen
			if o["rect"].contains(pygame.Rect((mouse[0]-(r/2),mouse[1]-(r/2),r,r))):		
				
				# bebaubar test
				#	--------------------------
				for x in range(o["pos"][0],o["pos"][0]+neu[b]["size"][0]):		# von position bis position + size
					for y in range(o["pos"][1],o["pos"][1]+neu[b]["size"][1]):
						# gehe links nach
						if monde[x][y].get("link") != None:
							if monde[monde[x][y]["link"][0]][monde[x][y]["link"][1]]["bauen"] == 0:
								ok = False
						# gibt est eine Koordinate, die nicht bebaubar ist, wird ok = False							
						elif monde[x][y]["bauen"] == 0:
							ok = False
				del x , y   	# da x und y häufig sind
				
				# ist alles bebaubar, geht's los!
				# -------------------------------------
				if ok == True:
					obj = monde[o["pos"][0]][o["pos"][1]]		# temp var , besser manipulierbar als monde	
					
					bauen = obj	# hérédité der alten eigenschaften
					# ungeschickt alle attribute manuell festzulegen , besser iter oder so
					bauen["type"] = b
					bauen["bauen"] = 0
					bauen["size"] = neu[b]["size"]		# needed by korrektur
					bauen["img"] = neu[b]["img"] 		# needed by korrektur
					bauen["datei"] = neu[b]["datei"] 		
					bauen["rect"] = bauen["img"].get_rect()		# needed by korrektur
					if neu[b].get("prod") != None:
						bauen["prod"] = neu[b]["prod"]
					# korrektur + positionieren
					korrektur = bauen["rect"].height - bauen["size"][1]*s[1]+s[1]		# warum +60?
					bauen["dpos"] = [obj["npos"][0],obj["npos"][1]-korrektur]
					bauen["rect"] = bauen["rect"].move(bauen["dpos"])
					
	# mouse depressed (hehe)
	#---------------------------------					
	if (pygame.mouse.get_pressed()[0] == False) and (bauen.get("pos") != None):		# ist überhaubt gebaut woden?
		monde[bauen["pos"][0]][bauen["pos"][1]] = bauen		# übergabe von temp var bauen
		if neu[b].get("prod") != None:
			players[pla]["geb"][b][str(bauen["pos"])] = {}
			players[pla]["geb"][b][str(bauen["pos"])]["pos"] = bauen["pos"]
			players[pla]["geb"][b][str(bauen["pos"])]["prod"] = neu[b]["prod"]
			players[pla]["geb"][b][str(bauen["pos"])]["prodv"] = neu[b]["prodv"]
			players[pla]["geb"][b][str(bauen["pos"])]["spe"] = {neu[b]["prod"]:0.0}
			players[pla]["geb"][b][str(bauen["pos"])]["reqfeld"] = neu[b]["reqfeld"]
		if bauen["type"] == 15:
			players[pla]["geb"][b][str(bauen["pos"])] = {}
			players[pla]["geb"][b][str(bauen["pos"])]["spe"] = {}
			players[pla]["geb"][b][str(bauen["pos"])]["pos"] = bauen["pos"]			
			for key in gueter:
				players[pla]["geb"][b][str(bauen["pos"])]["spe"][key] = 0
		print "baue Haus auf " + str(bauen["pos"])  
		# erstellen der Links 
		for x in range(bauen["pos"][0],bauen["pos"][0]+bauen["size"][0]):		# siehe test ob bebaubar
			for y in range(bauen["pos"][1],bauen["pos"][1]+bauen["size"][1]):
				if not ((x == bauen["pos"][0]) and (y == bauen["pos"][1])):		# erste koordinate natürlich nicht überschreiben (ref)
					npos = monde[x][y]["npos"]
					monde[x][y] = {"pos" : monde[x][y]["pos"] , "link" : bauen["pos"] , "npos":npos}	# links
		bauen = {"type" : bauen["type"] } # reset von bauen
		cost = neu[b]["cost"]
	return {"monde" : monde,"bauen" : bauen , "cost": cost,"players":players}  # ausgabe von monde und bauen , bauen ermöglicht ein beibehalten der zu bauenden felder




	
def delete(monde,draw,leute,mouse,neu,bauen,z,players,pla):
	s=[]
	r=0
	cost=0
	if z == 0:
		s = [26,15]
		r=10
	elif z == 1:
		s = [52,30]
		r=20
	elif z == 2:
		s = [104,60]
		r=40
	b = 1
	### nur wenn linke maustaste down
	if pygame.mouse.get_pressed()[0] == True:
		### heraussuchen des aktuellen Felds aus den angezeigten Felder 
		for o in draw:
			if o["rect"].contains(pygame.Rect((mouse[0]-(r/2),mouse[1]-(r/2),r,r))):
				if o["size"] == [1,1]:		# bei einfachen objekten
					obj = monde[o["pos"][0]][o["pos"][1]]		# temp variabel, so das das arbeiten einfacher wird
					## erstes Feld markiert begin des zu zeichnenden Feldes 
					if bauen.get("begin") == None:		
						bauen["begin"] = obj["pos"]  
					## aktuelles Feld markiert ende des Feld Rechtecks	
					bauen["end"] = obj["pos"] 
					bauen["rect"] = [[],[]]
					## Rechteck erstellen
					if bauen["end"][0] - bauen["begin"][0] >= 0:	## x richtung
						bauen["rect"][0] = range(bauen["begin"][0] , bauen["end"][0]+1)
					if bauen["end"][0] - bauen["begin"][0] <= 0:	## -x richtung
						bauen["rect"][0] = range(bauen["end"][0] , bauen["begin"][0]+1)
					if bauen["end"][1] - bauen["begin"][1] >= 0:	## y richtung
						bauen["rect"][1] = range(bauen["begin"][1] , bauen["end"][1]+1)
					if bauen["end"][1] - bauen["begin"][1] <= 0:	## -y richtung
						bauen["rect"][1] = range(bauen["end"][1] , bauen["begin"][1]+1)
				
				if o["size"] != [1,1]:		# für objekte wie häuser
					bauen["rect"] = [[],[]]
					bauen["rect"][0] = range(o["pos"][0],o["pos"][0]+o["size"][0])
					bauen["rect"][1] = range(o["pos"][1],o["pos"][1]+o["size"][1])
					bauen["begin"] = o["pos"] 
					bauen["end"] = [o["pos"][0]+o["size"][0],o["pos"][1]+o["size"][1]]
					if players[pla]["geb"][o["type"]].get(str(o["pos"])) != None:
						del players[pla]["geb"][o["type"]][str(o["pos"])]

	### wird maustaste  losgelassen
	if (pygame.mouse.get_pressed()[0] == False) and (bauen.get("rect") != None):
		rect = bauen["rect"] 
		print "baue Feld von " + str(bauen["begin"]) + " bis " + str(bauen["end"]) + "vom Typ " + str(bauen["type"])
 		## jedes Feld in bauen durchgehen, so dass ein Rechteck von begin zu ende entsteht
		for i in rect[0]:
			for i2 in rect[1]:
				obj2 = monde[i][i2] # erneute temp variabel
				# folge links: ist link existent aund bauen true , oder ist link inexistent und bauen true
			#	if ((obj2.get("link") == None)):
				obj2["img"] = neu[b]["img"]  # kopiere img aus neu 
				obj2["datei"] = neu[b]["datei"]  # kopiere datei namen aus neu 
				obj2["rect"] = obj2["img"].get_rect() 
				## errechnen der Korrektur (1 und 2 sind gleich null!)
				## rest 
				obj2["dpos"] = [obj2["npos"][0],obj2["npos"][1]]
				obj2["rect"] = obj2["rect"].move(obj2["dpos"])
				obj2["type"] = 1
				obj2["bauen"] = 1
				obj2["korr"] = 0
				obj2["size"] = [1,1]
				if obj2.get("link") != None:
					del obj2["link"]
				monde[i][i2] = obj2
				
		if players[pla]["geb"].get(str(bauen["begin"])) != None:
			del players[pla]["geb"][str(bauen["begin"])]
		leute2=leute[:]
		for l in leute:
			if (l["dest_pos"] == bauen["begin"])  or   (l["source_pos"] == bauen["begin"]):
				del leute2[leute2.index(l)] 
		leute = leute2[:]
		bauen = {"type" : bauen["type"] } # reset von bauen
	return {"monde" : monde,"bauen" : bauen,"players":players,"leute":leute}  # ausgabe von monde und bauen , bauen ermöglicht ein beibehalten der zu bauenden felder
